# Setux Core

[Setux] Base classes.

[PyPI] - [Repo] - [Doc]


[PyPI]: https://pypi.org/project/setux_core
[Repo]: https://github.com/louis-riviere-xyz/setux_core
[Doc]: https://setux-core.readthedocs.io/en/latest
[Setux]: https://setux.readthedocs.io/en/latest
